<?php
  header('Content-type: text/html; charset=utf-8', true);
  header('Cache-control: no-cache', true);
  header('Pragma: no-cache');

  ini_set( "display_errors", 1 );
  ini_set( "error_reporting", E_ALL );
  
  include_once '../includes/globals.php';
  include_once '../includes/aibridge.class.php';
  include_once '../includes/rosetta.class.php';
  
  $result = AIBridge::getProcessResult( $_GET['processID']);
  $xml = new XMLDocument($result);
  $xpath = xpath_new_context($xml->document_element());

  $diagOutput = @xpath_eval($xpath, '/diagOutput');
  if (count($diagOutput->nodeset) > 0)
  {
    $diagOutput = $diagOutput->nodeset[0];
    $numberOfFailures = $diagOutput->get_attribute('testsFailed');
    $numberOfWarnings = $diagOutput->get_attribute('testsPassedWithWarnings');
  }
  else
  {
    $numberOfFailures = 0;
    $numberOfWarnings = 0;
  }

  $stateEnum["passed"]             = 0;
  $stateEnum["passedWithWarnings"] = 1;
  $stateEnum["failed"]             = 2;

  outputViewHeader();

  echo '<script type="text/javascript" src="../js/lib.js"></script>';
  echo '<script type="text/javascript" src="js/diagnoseResult.js"></script>';
  echo '<script type="text/javascript">';
  $DIAGNOSE_STATUS = array();
  $DIAGNOSE_STATUS["failureCount"] = $numberOfFailures;
  $DIAGNOSE_STATUS["warningCount"] = $numberOfWarnings;
  echo ('DIAGNOSE_STATUS = ' . Rosetta::arrayToJSON($DIAGNOSE_STATUS) . ";\n");
  echo '</script>';
  echo '</head>';
  echo ('<body onload="init(' . ((DEBUG_MODE === true) ? 'true' : 'false') . ');">');

  // Add drop-down select box to choose which results to display.
  echo '<select id="diagnoseResultViewSelectDropDown" size="1">';
  echo ('  <option value="all" selected="selected">' . translate('MSG_SHOW_ALL_RESULTS') . '</option>');
  echo ('  <option value="errorsAndWarnings">' . translate('MSG_SHOW_ERRORS_AND_WARNINGS') . '</option>');
  echo ('  <option value="errorsOnly">' . translate('MSG_SHOW_ERRORS_ONLY') . '</option>');
  echo '</select>';
  echo  '<div id="diagnoseResult">';

  $actions = array();
  $diagnosisResults = @xpath_eval($xpath, '/diagOutput/diagnosisResult');
  foreach ($diagnosisResults->nodeset as $diagnosisResult)
  {
    // Need to get the state of all nested results to determine the state of the parent result.
    // If the nested result's state is greater than the parent result's state (according to $stateEnum)
    // then assign the parent's state to be equal to that.
    $state = getResultState( $diagnosisResult );
    $nestedResults = $diagnosisResult->get_elements_by_tagname("diagnosisResult");
    foreach ($nestedResults as $nestedResult)
    {
      $nestedState = getResultState( $nestedResult );
      if ( $stateEnum[$nestedState] > $stateEnum[$state] )
        $state = $nestedState; 
    }

    // Use the state as the class name for visible components to be either shown or hidden
    // depending on the user's selection ( e.g. "all", "errorsAndWarnings", or "errorsOnly" )
    $caption = $diagnosisResult->get_attribute('caption');
    echo  ('<h2 class="' . $state . '">' . $caption . '</h2>');
    if (count($nestedResults) > 0)
    {
      foreach ($nestedResults as $nestedResult)
      {
        $state = getResultState( $nestedResult );
        $caption = $nestedResult->get_attribute('caption');
        echo  ('<h3 class="' . $state . '">' . $caption . '</h3>');
        parseLeaf($nestedResult);
      }
    }
    else
    {
      parseLeaf($diagnosisResult);
    }
  }

  echo  '</div>';
  echo '<script type="text/javascript">';
  echo ('DEVICE_ACTIONS = ' . Rosetta::arrayToJSON($actions) . ";\n");
  echo '</script>';

  outputViewFooter();

  function getResultState( $diagnosisResult )
  {
    $errors = $diagnosisResult->get_elements_by_tagname( 'error' );
    $warnings =  $diagnosisResult->get_elements_by_tagname( 'warning' );
    $resultState = 'passed';
    if ( count( $errors ) > 0 )
      $resultState = 'failed';
    else if ( count( $warnings ) > 0 )
      $resultState = 'passedWithWarnings';
    return $resultState;
  }
  
  function parseLeaf(&$result)
  {
    $component = $result->get_attribute('component');
    $state = getResultState( $result );
    $timestamp = $result->get_attribute('time');
    echo  '<div class="' . $state . '">';
    if ($timestamp != "")
      echo  ('<label class="timestamp">' . $timestamp . '</label>');
    echo  '<p class="result">';
    if ($state == 'passed')
    {
      echo  '<img class="icon" src="../images/status_passed.gif" />';
      echo  translate('MSG_PASSED');
    }
    else if ($state == 'passedWithWarnings')
    {
      echo  '<img class="icon" src="../images/status_warning.gif" />';
      echo  translate('MSG_PASSED_WITH_WARNINGS');
    }
    else if ($state == 'failed')
    {
      echo  '<img class="icon" src="../images/status_failed.gif" />';
      echo  translate('MSG_FAILED');
    }
    else
    {
      echo  '<img class="icon" src="../images/status_unknown.gif" />';
      echo  translate('MSG_UNKNOWN');
    }
    $warnings = $result->get_elements_by_tagname('warning');
    $errors = $result->get_elements_by_tagname('error');
    if (count($warnings) > 0 || count($errors) > 0)
    {
      echo  '<table class="errorsAndWarnings">';
      foreach ($errors as $error)
      {
        $caption = $error->get_attribute('caption');
        $code = $error->get_attribute('code');
        if ($code == "")
          $code = $error->get_attribute('errorCode');
        echo  '<tr class="error">';
        echo  ('<th>' . translate('MSG_ERROR') . ':</th>');
        if ($code != "")
        {
          echo  ('<td>' . $code . ':</td>');
          echo  ('<td>' . $caption . '</td>');
        }
        else
        {
          echo  ('<td colspan="2">' . $caption . '</td>');
        }
        echo  '</tr>';
      }
      foreach ($warnings as $warning)
      {
        $caption = $warning->get_attribute('caption');
        echo  '<tr class="warning">';
        echo  ('<th>' . translate('MSG_WARNING') . ':</th>');
        echo  ('<td colspan="2">' . $caption . '</td>');
        echo  '</tr>';
      }
      echo  '</table>';
    }
    echo  '</p>';
    $infos = $result->get_elements_by_tagname('info');
    foreach ($infos as $info)
    {
      $infoCaption = $info->get_attribute('caption');
      $infoContent = $info->get_content();
      echo  '<p class="infoCaption">';
      echo  '<img class="icon" src="../images/status_unknown.gif" />';
      echo  $infoCaption . " " . $infoContent;
      echo  '</p>';
    }
    $files = $result->get_elements_by_tagname('formattedTextFile');
    foreach ($files as $file)
    {
      $filepath = (DIAGS_DIRECTORY . LANG . '/' . $file->get_attribute('filename'));
      if (file_exists($filepath))
        echo  ('<div class="formattedText">' . file_get_contents($filepath) . '</div>');
      else
        echo  ('<div class="formattedText">' . $filepath . '</div>');
    }

    reset($infos);
    global $actions;
    $deviceActions = $result->get_elements_by_tagname('deviceAction');
    foreach ($deviceActions as $action)
    {
      $actionArray = array();
      $actionCaption = $action->get_attribute('caption');
      $actionArray['caption'] = $actionCaption;
      $actionArray['component'] = $action->get_attribute('component');
      $actionArray['device'] = $action->get_attribute('device');
      $actionArray['subDevice'] = $action->get_attribute('subDevice');
      $actionArray['tcLoadFilename'] = ($component . '.dat');
      $actionArray['call'] = extractActionCall($action);
      $actions[] = $actionArray;
      $actionID = (count($actions) - 1);
      echo  ('<div class="subbutton" onclick="performAction(' . $actionID . ');">' . $actionCaption . '</div><br class="clear" />');
    }
    echo  '<hr>';
    echo  '</div>';
  }
  
  // UTILITY FUNCTIONS

  function extractActionCall($action)
  {
    $returnVal = '';
    $actionCalls = $action->child_nodes();
    foreach ($actionCalls as $call)
    {
      if ($call->node_type() == XML_ELEMENT_NODE)
        $returnVal = $call->tagname;
    }
    return $returnVal;
  }
?>
